import logging
import os
import sys
import traceback

import openobserve

stream_global = 'default'
organization_global = 'default'

logs_dir = os.path.join(os.path.expanduser('~'), '.openobserve', 'logs')

if not os.path.exists(logs_dir):
    os.makedirs(logs_dir)

logging.basicConfig(filename=logs_dir + '/log.log', level=logging.ERROR, format='%(asctime)s:%(levelname)s:%(message)s')
openobserve.additional_info = True


def log_unhandled_exceptions(exctype, value, tb) -> None:
    global stream_global, organization_global

    openobserve.send(
        job=str(exctype.__name__),
        message=str(value),
        level='FATAL_ERROR',
        traceback=str("".join(traceback.format_tb(tb))),
        _stream=stream_global,
        _organization=organization_global
    )

    logging.error(str(exctype.__name__) + ' ' + str(value) + ' - ' + str("".join(traceback.format_tb(tb))))


sys.excepthook = log_unhandled_exceptions



import inspect
import platform
import socket


def debug_data() -> object:
    debug = {
        'hostname': socket.gethostname(),
        'user_name': socket.gethostname(),
        'system': platform.system(),
        'system_architecture': platform.machine(),
        'system_version': platform.version(),
        'system_release': platform.release(),
        'python_version': platform.python_version()
    }

    try:
        frame = inspect.currentframe()
        caller_frame = frame.f_back.f_back
        info = inspect.getframeinfo(caller_frame)
        debug['filename'] = info.filename
        debug['lineno'] = info.lineno
    except:
        pass

    return debug



import json
import os
from typing import Any
import threading

import requests
from jsonex import JsonEx
from requests.auth import HTTPBasicAuth

import openobserve.generate

username = ''
password = ''
host = 'http://127.0.0.1:5080'
stream_global = 'default'
organization_global = 'default'
ssl_verify = False
timeout = 3
additional_info = False
enable_threading = True
logs_dir = os.path.join(os.path.expanduser('~'), '.openobserve', 'logs')

if not os.path.exists(logs_dir):
    os.makedirs(logs_dir)

def _send_request(data, url):
    try:
        response = requests.post(
            url=url,
            data=JsonEx.dump([data]),
            auth=HTTPBasicAuth(username, password),
            verify=ssl_verify,
            timeout=timeout
        )

        response_data = json.loads(response.content)

        if response_data['status'][0]['failed'] > 0:
            print("Failed to send data:", str(response.content))
            return False

        return response
    except Exception as e:
        print("Error during sending data:", str(e))
        return False


def send(
        job: Any = '',
        level: str = 'INFO',
        _stream: str = None,
        _organization: str = None,
        _return_data: bool = False,
        **kwargs
) -> Any:
    global host, username, password, stream_global, organization_global, ssl_verify, timeout, additional_info, enable_threading

    _stream = _stream if _stream is not None else stream_global
    _organization = _organization if _organization is not None else organization_global
    url = host + '/api/' + _organization + '/' + _stream + '/_json'
    debug = {} if additional_info is False else openobserve.generate.debug_data()

    data = {
        **{
            'job': job,
            'level': level
        },
        **debug,
        **kwargs
    }

    if _return_data:
        return data

    if enable_threading:
        thread = threading.Thread(target=_send_request, args=(data, url))
        thread.start()
        return thread
    else:
        return _send_request(data, url)
